@@ -109,17 +109,21 @@ class PavlovADM(Cmd):
 			cmd = self._cmdselects(srv)
 			if not cmd:
 				continue
-			elif cmd == '<Disconnect>':
+			cmd = cmd.strip('<>')
+			if self.dbg:
+				print(bgre(cmd))
+			if cmd == 'Disconnect':
 				self.maps = None
 				self.banlist = None
 				self.hlp = None
 				break
-			if cmd == 'RefreshList':
+			elif cmd == 'RefreshList':
 				res = self._players(srv)
 			else:
 				res = self.rconexec(srv, cmd.strip('<>'))
-			if res:
-				print(tabd(res))
+			if isinstance(res, dict):
+				res = tabd(res)
+			print(res)
 		self.serverselect()
 
 	def _getmapname(self, mapid):
@@ -250,35 +254,42 @@ class PavlovADM(Cmd):
 	def _getcash(self):
 		c = 0
 		while True:
-			cash = input('enter amount of cash (as number)')
+			print('enter amount of cash (as number): ', end='')
+			cash = input()
 			if cash.isdigit():
 				return cash
 			c+=1
 			if c < 3:
-				error('thats not a number - let\'s try again')
+				error('thats not a number - let\'s try that again!')
 			else:
 				error('too dumb for numbers? o.0 aborting...')
 
 	def _cmdselects(self, srv):
-		noargs = ['Info', 'ResetSND', 'RefreshList', 'RotateMap', 'ServerInfo', 'Help', '<Disconnect>']
+		noargs = ['Info', 'ResetSND', 'RefreshList', 'RotateMap', 'ServerInfo', 'Help', 'Disconnect']
 		steams = ['Kick', 'Ban', 'Unban', 'InspectPlayer']
 		others = ['SwitchMap', 'SwitchTeam', 'GiveItem', 'GiveCash', 'GiveTeamCash', 'SetPlayerSkin', 'SetLimitedAmmoType']
-		order = ['Info', 'SwitchMap', 'RotateMap', 'ResetSND', 'Kick', 'Ban', 'Unban', 'InspectPlayer', 'GiveItem', 'GiveCash', 'GiveTeamCash', 'SetPlayerSkin', 'SetLimitedAmmoType', 'RefreshList', 'ServerInfo', '<Disconnect>']
-		self.hlp = self.hlp if self.hlp else self.rconexec(srv, 'Help')['Help']
-		hlp = [h.split(' ')[0] for h in self.hlp.split(', ') if h.split(' ')[0]] + ['Info']
+		order = ['Info', 'SwitchMap', 'Kick', 'ResetSND', 'InspectPlayer', 'GiveItem', 'GiveCash', 'GiveTeamCash', 'SetPlayerSkin', 'SetLimitedAmmoType', 'RefreshList', 'ServerInfo',  'RotateMap', 'Ban', 'Unban']
+		if self.hlp is None:
+			hlp = self.rconexec(srv, 'Help')
+			if not hlp or 'Help' not in hlp.keys():
+				return error('no or malformed help received from the server')
+			hlp = hlp['Help']
+			self.hlp = [h.split(' ')[0] for h in hlp.split(', ') if h.split(' ')[0]]
+		opts = ['Info'] + [o for o in order if o in self.hlp and not o == 'Disconnect']
+		opts = opts + [h for h in self.hlp if h not in opts + ['Disconnect']] + ['<Disconnect>']
 		ask = [
             iList(
                 'cmd',
                 carousel=True,
                 message='select command',
-                choices=[o for o in order if o.strip('<>') in hlp],
+                choices=opts,
             ),
         ]
 		try:
 			cmd = list(prompt(ask).values())[0].strip()
 		except AttributeError:
 			exit()
-		if cmd in noargs:
+		if cmd.strip('<>') in noargs:
 			return cmd
 		elif cmd in steams:
 			sid = self._getsteamid(srv, cmd)
@@ -324,6 +335,7 @@ class PavlovADM(Cmd):
 
 	def _sid2name(self, sids):
 		namesids = {}
+		c = 0
 		for s in sids:
 			s = s.strip()
 			res, _ = Popen('curl -q https://steamdb.info/calculator/%s/'%s, stdout=PIPE, stderr=DEVNULL, shell=True).communicate()
@@ -332,12 +344,12 @@ class PavlovADM(Cmd):
 				r = r.strip()
 				if r.startswith('<title>'):
 					n = r.split('>')[1].split(' · Steam Calculator')[0]
-					namesids[s] = n
+					namesids[n] = s
 					break
-			sleep(2)
+			c = c+1
+			if c >= 2:
+				sleep(2)
 		return namesids
-		#https://steamcommunity.com/friends/add
-		#https://steamcommunity.com/profiles/76561197970711320/friends/add
 
 	def _getbanlist(self, srv):
 		if self.banlist is None:
@@ -352,19 +364,11 @@ class PavlovADM(Cmd):
 				return
 			with open(blacklist, 'r') as bfh:
 				banlist = bfh.readlines()
-				self.banlist = self._sid2name([l for l in list(banlist) if l])
-				#curl -q https://steamdb.info/calculator/$SSID/ 2>/dev/null |grep '^<title>' |awk -F'>' '{print $2}' |sed 's/\s.\sSteam.//' 
-				#res = post('https://steamdb.info/calculator/%s'%l)
-				#for r in res.text.split('\n'):
-				#	if 'actual_persona_name' in r:
-				#		self.banlist[r.split('>')[1].split('<')[0]] = l
-				#		break
+			self.banlist = self._sid2name([l for l in list(banlist) if l])
 		return self.banlist
 
 	def _getsteamid(self, srv, cmd):
 		userids = self._players(srv)
-		if self.dbg:
-			print(bgre(userids))
 		if cmd == 'Unban':
 			if len(self.servers[srv]) != 3:
 				print('no blacklist present - manual input required, ', end='')
@@ -378,7 +382,7 @@ class PavlovADM(Cmd):
 					if not sid: return
 					name = self._sid2name([sid])
 					if name:
-						name = name[sid]
+						name = list(name.keys())[0]
 					print('are you sure you want to unban the player "%s" with steam-id the "%s"? [Y/n]'%(name, sid))
 					yesno = input()
 					if str(yesno).lower() in ('', 'y'):
@@ -413,16 +417,6 @@ class PavlovADM(Cmd):
 		for p in pout:
 			players[p['Username']] = p['UniqueId']
 		return players
-		#pout = pout.split('{\n\t"PlayerList": [')[1]
-		#pout = pout.split('\t]\n}')[0]
-		##print(pout)
-		#_players = {}
-		#for blk in pout.split('}'):
-		#	useruid = [l.strip() for l in blk.rstrip('}').split('\n') if l.strip() and l.strip() not in (',', '{')]
-		#	if not useruid or str(useruid).strip() == '[\']\']': continue
-		#	#print(useruid)
-		#	_players[useruid[0].split('": "')[1].rstrip('",')] = useruid[1].split('": "')[1].rstrip('"')
-		#return _players
 
 	def _getresponse(self, socket):
 		res = []
@@ -454,7 +448,8 @@ class PavlovADM(Cmd):
 			if res:
 				res = jload(res)
 		except JSONDecodeError as err:
-			error('while parsing', res, 'an exception', err, 'occured')
+			if res.strip() != 'Goodbye':
+				error('while parsing', res, 'an exception', err, 'occured')
 		except TimeOutError:
 			self.cnt += 1
 			if self.cnt <= 2:
